pub enum CycleDetector<T> {
Unprocessed,
Processing,
Cyclic,
Processed(T),
}Expand description
An enum to manage potentially-cyclic computations.
Variants
Unprocessed
We haven’t analyzed this yet.
Processing
Sentinel value that we set when starting the computation on an item. If we ever encounter this, we know we encountered a loop that we can’t handle.
Cyclic
Sentinel value we put when encountering a cycle, so we can know that happened.
Processed(T)
The final result of the computation.
Implementations
Sourceimpl<T> CycleDetector<T>
impl<T> CycleDetector<T>
Sourceimpl<T> CycleDetector<T>
impl<T> CycleDetector<T>
pub fn as_unprocessed_mut(&mut self) -> Option<()>
pub fn as_processing_mut(&mut self) -> Option<()>
pub fn as_cyclic_mut(&mut self) -> Option<()>
pub fn as_processed_mut(&mut self) -> Option<&mut T>
Sourceimpl<T> CycleDetector<T>
impl<T> CycleDetector<T>
Sourcepub fn start_processing(&mut self) -> bool
pub fn start_processing(&mut self) -> bool
If this item hadn’t been processed, return true and record it as Processing, otherwise
return false. If this item is already processing, record a cycle.
pub fn done_processing(&mut self, x: T)